==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/layouts/activity-panel/en.dictionary.itop.activity-panel.php <==
<?php
/**
 * Copyright (C) 2013-2024 Combodo SAS
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */

// Activity panel
Dict::Add('EN US', 'English', 'English', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Expand',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Reduce',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Close',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Load more entries',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Load all previous entries',

	// Tabs
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Activity',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Draft entry',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Logs',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Show / hide logs entries on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Choose which logs to display on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'State changes',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Show / hide state changes on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Edits',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Show / hide fields edits on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Open all entries',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Close all entries',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Number of persons interacting in the visible entries',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Number of messages in the visible log(s)',

	// Compose button
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Compose a new log entry',

	// Case log entry
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Multiple logs save',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'By pressing the "save" button, you will submit entries for all the edited logs at once.',

	// Notification entry
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Click to open the notifications tab and get more information',

	// Placeholder
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'It\'s calm up here, no activity yet',

	// Closed cover
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Activity panel',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Click to open the activity panel',
));

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/layouts/activity-panel/en.dictionary.itop.activity-panel.php <==
<?php
/**
 * Copyright (C) 2013-2024 Combodo SAS
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */

// Activity panel
Dict::Add('EN US', 'English', 'English', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Expand',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Reduce',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Close',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Load more entries',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Load all previous entries',

	// Tabs
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Activity',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Draft entry',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Logs',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Show / hide log entries on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Choose which logs to display on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'State changes',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Show / hide state changes on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Edits',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Show / hide fields edits on this tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Open all entries',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Close all entries',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Number of persons interacting in the visible entries',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Number of messages in the visible log(s)',

	// Compose button
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Compose a new log entry',

	// Case log entry
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Multiple logs save',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'By pressing the "save" button, you will submit entries for all the edited logs at once.',

	// Notification entry
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Click to open the notifications tab and get more information',

	// Placeholder
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'It\'s calm up here, no activity yet',

	// Closed cover
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Activity panel',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Click to open the activity panel',
));
